@@ -191,15 +191,7 @@ MainWindow::MainWindow()
 	//////////////////////////////////////////////////////////////////	
 	//#### init(listen to) and set the default orientation 
 	//////////////////////////////////////////////////////////////////	
-	if ( _settingsWindow->getOrientation() == "AUTO" )
-	{
-		initOrientation();
-		setLandscape(); // default
-	}
-    else if (_settingsWindow->getOrientation() == "LANDSCAPE") setLandscape();
-    else if (_settingsWindow->getOrientation() == "PORTRAIT") setPortrait();
-
-    
+	initOrientation();
    //////////////////////////////////////////////////////////////////	
 
     // CONNECT ALL BUTTONS AND WIDGET TO THEIR SLOTS
@@ -308,12 +300,27 @@ void MainWindow::createMenus()
 // CONNECTS THE ACCELEROMETER USING DBUS to listen to orientation changes in AUTO mode only
 void MainWindow::initOrientation()
 {
-	QDBusConnection::systemBus().call(QDBusMessage::createMethodCall(MCE_SERVICE, MCE_REQUEST_PATH,
+	if ( _settingsWindow->getOrientation() == "AUTO" )
+	{
+		QDBusConnection::systemBus().call(QDBusMessage::createMethodCall(MCE_SERVICE, MCE_REQUEST_PATH,
 							MCE_REQUEST_IF, MCE_ACCELEROMETER_ENABLE_REQ));
 
-	QDBusConnection::systemBus().connect(QString(), MCE_SIGNAL_PATH, MCE_SIGNAL_IF,
+		QDBusConnection::systemBus().connect(QString(), MCE_SIGNAL_PATH, MCE_SIGNAL_IF,
 			                MCE_DEVICE_ORIENTATION_SIG, this, SLOT(orientationChanged(QString)));
-
+		setLandscape(); // default
+	}
+    else if (_settingsWindow->getOrientation() == "LANDSCAPE") 
+	{
+		QDBusConnection::systemBus().call(QDBusMessage::createMethodCall(MCE_SERVICE, MCE_REQUEST_PATH,
+							MCE_REQUEST_IF, MCE_ACCELEROMETER_DISABLE_REQ));
+		setLandscape();
+	}
+    else if (_settingsWindow->getOrientation() == "PORTRAIT")
+	{
+		QDBusConnection::systemBus().call(QDBusMessage::createMethodCall(MCE_SERVICE, MCE_REQUEST_PATH,
+							MCE_REQUEST_IF, MCE_ACCELEROMETER_DISABLE_REQ));
+		setPortrait();
+	}
 }
 
 // SLOT when orientation change is detected
@@ -666,7 +673,7 @@ void MainWindow::showRecordMessage()
 		_infoapi->sendRecordMsg(dataToSender);
 
 		QMessageBox::StandardButton reply;
-		reply = QMessageBox::information(this, "<b>PLEASE READ THIS WARNING<\b>", info1+info2+info3+recordMsg);
+		reply = QMessageBox::information(this, "PLEASE READ THIS WARNING", info1+info2+info3+recordMsg);
 	}
 
 	clearProg();  // clear selected programmes
@@ -684,21 +691,21 @@ void MainWindow::showRemindMessage()
 		//qDebug() << "Alarm Start Time : " << progSTime << " Alarm End time : " << progETime;
 
 		QString remindTitle = _channelDataMap[progKey].title + " on channel " + _channelDataMap[progKey].channelId;
-		QString remindMessage = "This is a reminder of your favourite show from the SHOWTIME app on the Nokia N900";
+		QString remindMessage = "This is a reminder of your favourite show from the SHOWTIME APP on the Nokia N900";
 
 		if ( _settingsWindow->getRemindType() == "EVENT" )	
 		{
 			_reminderManager->addEvent("SHOWTIME", progSTime, progETime, remindTitle, remindMessage, 1);
-			QMaemo5InformationBox::information(this, "EVENTS WERE ADDED TO YOUR SHOWTIME CALENDAR" , QMaemo5InformationBox::NoTimeout);
 		}
         else if ( _settingsWindow->getRemindType() == "ALARM" )	
 		{
 			_reminderManager->addAlarmEvent("SHOWTIME", progSTime, remindTitle, progSTime, progETime, remindMessage);
-			QMaemo5InformationBox::information(this, "ALARMS WERE ADDED FOR YOUR SELECTED PROGRAMMES 15min BEFORE THEY START" , QMaemo5InformationBox::NoTimeout);
 		}
 
 	}
 
+	QMaemo5InformationBox::information(this, "<b>YOUR SHOWTIME CALENDAR HAS BEEN UPDATED WITH YOUR SELECTED PROGRAMMES<\b>" , QMaemo5InformationBox::NoTimeout);
+
 	clearProg();  // clear selected programmes
 }
 
@@ -837,6 +844,8 @@ void MainWindow::showFavourite()
 	_favouriteWindow = new FavouriteWindow(this);
 	_favouriteWindow->setAttribute(Qt::WA_Maemo5StackedWindow);
 
+	connect(_favouriteWindow, SIGNAL(clicked()), this, SLOT(reInitFavouriteSettings()));
+
 	_favouriteWindow->show();
 }
 
@@ -859,10 +868,19 @@ void MainWindow::showSettings()
 	_miscWindow = new MiscSettingsWindow(this);
 	_miscWindow->setAttribute(Qt::WA_Maemo5StackedWindow);
 
+	connect(_miscWindow, SIGNAL(clicked()), this, SLOT(reInitMiscSettings()));
+
 	_miscWindow->show();
 }
 
-// reloads the settings , clears all data
+// SLOT::reloads the favourite settings
+void MainWindow::reInitFavouriteSettings()
+{
+	initAppSettings();
+	_favouriteWindow->close();
+}
+
+// SLOT::reloads the settings , clears all data
 // and starts afresh with newly selected region
 void MainWindow::reInitInfoAccess()
 {
@@ -880,7 +898,27 @@ void MainWindow::reInitInfoAccess()
 	_regionWindow->close();
 }
 
-// this function is called by the selectChannel slot when selected channel is FAVOURITES
+// SLOT::reloads the misc settings
+void MainWindow::reInitMiscSettings()
+{
+	initAppSettings(); // in case ALARM type is changed
+	initOrientation(); // in case Orientation is changed
+
+	// IN CASE ICON SET IS UPDATED
+	_recordButton->setIcon(QIcon(_settingsWindow->getIconPath() + "record.png"));
+	_remindButton->setIcon(QIcon(_settingsWindow->getIconPath() + "remind.png"));
+	_backToProgrammeListButton->setIcon(QIcon(_settingsWindow->getIconPath() + "back.png"));
+	_clearProgButton->setIcon(QIcon(_settingsWindow->getIconPath() + "clear.png"));
+	_goButton->setIcon(QIcon(_settingsWindow->getIconPath() + "go.png"));
+	_clearButton->setIcon(QIcon(_settingsWindow->getIconPath() + "clear.png"));
+	_programmeDetailButton->setIcon(QIcon(_settingsWindow->getIconPath() + "detail.png"));
+	_nextChannelButton->setIcon(QIcon(_settingsWindow->getIconPath() + "next.png"));
+	_prevChannelButton->setIcon(QIcon(_settingsWindow->getIconPath() + "prev.png"));
+
+	_miscWindow->close();
+}
+
+// SLOT::this function is called by the selectChannel slot when selected channel is FAVOURITES
 void MainWindow::loadFavourites()
 {
 	QStringList favourites = _settingsWindow->getFavourites(_settingsWindow->getRegion());
