@@ -17,6 +17,10 @@ public:
 
 public slots:
 
+signals:
+	void clicked();
+
+
 private slots:
 	void setLandscape();
 	void setPortrait();
